@@ -64,12 +64,14 @@ def main(config: MOVEConfig):
     data_of_interest = config.data.data_of_interest
     version = config.training.version
     
+    types = [[1, 0]]
+    
     cat_list, con_list, cat_names, con_names, headers_all, drug, drug_h = get_data(path, categorical_names, continuous_names, data_of_interest)
     
-    #train model
+#     #train model
     train_model_association(path, cuda, nepochs, nLatents, con_list, cat_list, version, repeats, kld_steps, batch_steps, lrate, drug)
     
-    #load files 
+    # Load files 
     results = np.load(path + "results/results_" + version + ".npy", allow_pickle=True).item()
     recon_results = np.load(path + "results/results_recon_" + version + ".npy", allow_pickle=True).item()
     groups = np.load(path + "results/results_groups_" + version + ".npy", allow_pickle=True).item()
@@ -77,41 +79,43 @@ def main(config: MOVEConfig):
     mean_bas = np.load(path + "results/results_recon_mean_baseline_" + version + ".npy", allow_pickle=True).item()
     recon_results_1 = np.load(path + "results/results_recon_no_corr_" + version + ".npy", allow_pickle=True).item()
     cor_results = np.load(path + "wp2.2/sig_overlap/cor_results_" + version + ".npy", allow_pickle=True).item()
-
-    recon_average = cal_reconstruction_change(recon_results)
+    
+    # Start analysis
+    recon_average = cal_reconstruction_change(recon_results, repeats)
     
     sig_hits, median_p_val = overlapping_hits(nLatents, cor_results, repeats, con_names, drug)
     
     all_hits, collected_overlap = identify_high_supported_hits(sig_hits, drug_h, version, path)
+    print(collected_overlap)
     
     report_values(path, sig_hits, median_p_val, drug_h, all_hits, con_names)
+    con_list_concat = np.concatenate(con_list, axis=-1)
     
-    recon_average_corr_new_all, recon_average_corr_all_indi_new = get_change_in_reconstruction(recon_average, groups, drug, drug_h, con_names, collected_overlap, sig_hits, np.concatenate(con_list, axis=-1), version, path)
+    recon_average_corr_new_all, recon_average_corr_all_indi_new = get_change_in_reconstruction(recon_average, groups, drug, drug_h, con_names, collected_overlap, sig_hits, con_list_concat, version, path, types)
+        
     
-    np.save(path + "results/results_confidence_recon_all_" + version + ".npy", recon_average_corr_new_all)
-    np.save(path + "results/results_confidence_recon_all_indi_" + version + ".npy", recon_average_corr_all_indi_new)
-
-    recon_average_corr_all_indi_new = np.load(path + "../../move/MOVE/results/results_confidence_recon_all_indi_" + version + ".npy", allow_pickle=True)
-
+    recon_average_corr_new_all = np.load(path + "results/results_confidence_recon_all_" + version + ".npy", allow_pickle=True)
+    
+    recon_average_corr_all_indi_new = np.load(path + "results/results_confidence_recon_all_indi_" + version + ".npy", allow_pickle=True).item()
+#     print(f'recon_average_corr_all_indi_new: {recon_average_corr_all_indi_new}')
     up_down_list = ['baseline_target_metabolomics', 'baseline_untarget_metabolomics']         
     
-    write_omics_results(path, up_down_list, collected_overlap, recon_average_corr_new_all, headers_all)
-    
-    data_dict = read_yaml('data')
-    con_dataset_names = data_dict['continuous_data_files']
+    write_omics_results(path, up_down_list, collected_overlap, recon_average_corr_new_all, headers_all, continuous_names, data_of_interest)
+
 
     # con_dataset_names = ['Clinical_continuous', 'Diet_wearables','Proteomics','Targeted_metabolomics','Unargeted_metabolomics', 'Transcriptomics', 'Metagenomics']
-    con_list_concat = np.concatenate(con_list, axis=1)
-    make_files(collected_overlap, groups, con_list_concat, path, recon_average_corr_all_indi_new, con_names, con_dataset_names, drug_h, drug, all_hits, version = version)
+    
+    
+    make_files(collected_overlap, groups, con_list_concat, path, recon_average_corr_all_indi_new, con_names, continuous_names, drug_h, drug, all_hits, types, version)
     
     
     df_indi_var = get_inter_drug_variation(con_names, drug_h, recon_average_corr_all_indi_new, 
-                                           groups, collected_overlap, drug, con_all, path)
+                                           groups, collected_overlap, drug, con_list_concat, path, types)
 
-    visualize_indi_var(df_indi_var, version)
-    visualize_drug_similarity_across_all(recon_average_corr_new_all, drug_h, version)
+    visualize_indi_var(df_indi_var, version, path)
+    visualize_drug_similarity_across_all(recon_average_corr_new_all, drug_h, version, path)
     
-    get_drug_similar_each_omics(con_names, con_dataset_names, all_hits, recon_average_corr_new_all, drug_h, version)
+    get_drug_similar_each_omics(con_names, continuous_names, all_hits, recon_average_corr_new_all, drug_h, version, path)
 
     
 if __name__ == "__main__":
